@@ -11,6 +11,7 @@ from cameo_claw.cameo_claw import it_chunk
 
 from pydantic import BaseModel
 import polars as pl
+import asyncio
 
 app = FastAPI()
 app.add_middleware(CORSMiddleware,
@@ -33,14 +34,19 @@ class ItemUrlFilter(BaseModel):
     sort_column: str = 'localTime'
 
 
-def it_streaming(i: ItemUrlFilter):
-    yield write_csv_header_to_gz(i)
-    for int_progress, bytes1 in it_chunk(
-            i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
-        if bytes1:
-            yield bytes1
-        else:
-            continue
+async def it_streaming(i: ItemUrlFilter):
+    try:
+        yield write_csv_header_to_gz(i)
+        for int_progress, bytes1 in it_chunk(
+                i.lst_url, i.target_directory, i.lst_distinct_column, i.lst_column_match, i.sort_column):
+            if bytes1:
+                yield bytes1
+            else:
+                continue
+    except asyncio.CancelledError:
+        print("caught cancelled error")
+    except Exception as e:
+        print('it_streaming,exception:', e)
 
 
 def write_csv_header_to_gz(i):
@@ -64,9 +70,10 @@ def streaming_post(i: ItemUrlFilter):
 
 @app.get("/api/streaming_get/")
 async def streaming_get(md5_hex):
+    print("🐲modify on server")
     dic = {'content-disposition': f"attachment; filename*=utf-8''all.csv.gz"}
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20425):
+def server(host='0.0.0.0', int_port=20426):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
